@@ -75,9 +75,9 @@ def setup(ctx, yes, teacher):
     settings['editor'] = choose_editor(settings.get('editor', 'atom'))
     if yes:
         click.echo(info("Updated settings:"))
-        click.echo(info(yaml.dump(read_settings()), preformatted=True))
+        click.echo(info(yaml.dump(settings), preformatted=True))
     else:
-        click.echo(info(yaml.dump(read_settings()), preformatted=True))
+        click.echo(info(yaml.dump(settings), preformatted=True))
         click.confirm(
             question("Do these settings look ok?"),
             abort=True
